Module concurrency_groups_api

Module concurrency_groups_api 

Enums

DeleteConcurrencyGroupError
struct for typed errors of method delete_concurrency_group
GetConcurrencyKeyError
struct for typed errors of method get_concurrency_key
ListConcurrencyGroupsError
struct for typed errors of method list_concurrency_groups
ListExtendedJobsError
struct for typed errors of method list_extended_jobs

Functions

delete_concurrency_group
get_concurrency_key
Requires read access to the job, the same as reading the run itself. Returns 403 for a workspace member who cannot see the run, and 404 when the caller is not a member of the job’s workspace.
list_concurrency_groups
list_extended_jobs