withdraw_hub_project

Function withdraw_hub_project 

pub async fn withdraw_hub_project(
    configuration: &Configuration,
    workspace: &str,
    slug: &str,
    folder: &str,
) -> Result<String, Error<WithdrawHubProjectError>>
Requires the caller to be a workspace admin. Forwards the request to the configured Hub scoped to the {workspace}:{folder} source and returns the Hub’s status code and raw response body. Everything pushed for the submission is kept, so it can be fixed and submitted again.