create_script

Function create_script 

pub async fn create_script(
    configuration: &Configuration,
    workspace: &str,
    new_script: NewScript,
) -> Result<String, Error<CreateScriptError>>
Creates a new script when the path does not already exist. Creates a new version of an existing script when called with the same path and the current parent_hash.