restart_worker_group

Function restart_worker_group 

pub async fn restart_worker_group(
    configuration: &Configuration,
    worker_group: &str,
) -> Result<String, Error<RestartWorkerGroupError>>
Send a restart signal to all workers in the specified worker group. Workers will gracefully shut down and are expected to be restarted by their supervisor. Requires devops role.