Module ai_session_backup_cursor

Module ai_session_backup_cursor 

Structs

AiSessionBackupCursor
AiSessionBackupCursor : where a pull of a session that did not fit one answer whole picks up; the rest of the session follows a pull naming that session alone with this as resume