pub struct AmqpExchange {
pub exchange_name: String,
pub routing_keys: Option<Vec<String>>,
}Fields
exchange_name: StringName of the exchange to bind the consumed queue to
routing_keys: Option<Vec<String>>Routing keys used to bind the queue to the exchange
Implementations
Sourceimpl AmqpExchange
impl AmqpExchange
pub fn new(exchange_name: String) -> AmqpExchange