pub struct AssetGraphRunnablesInner {
pub path: String,
pub usage_kind: AssetUsageKind,
pub in_pipeline: Option<bool>,
pub macros: Option<Vec<AssetGraphRunnablesInnerMacrosInner>>,
pub dbt: Option<Box<AssetGraphRunnablesInnerDbt>>,
}Fields
path: Stringusage_kind: AssetUsageKindin_pipeline: Option<bool>True iff the script is a pipeline member (deployed with // pipeline). Omitted when false.
macros: Option<Vec<AssetGraphRunnablesInnerMacrosInner>>Macros this script provides to the workspace registry (deployed // macros library). Omitted when empty.
dbt: Option<Box<AssetGraphRunnablesInnerDbt>>Implementations
Sourceimpl AssetGraphRunnablesInner
impl AssetGraphRunnablesInner
pub fn new(path: String, usage_kind: AssetUsageKind) -> AssetGraphRunnablesInner