Structs
- Create
AppRaw Source Request Value - CreateAppRawSourceRequestValue : The raw app’s value.
filesmaps each source path to its content and must contain an entry point;runnablesanddataare carried through unchanged.
files maps each source path to its content and must contain an entry point; runnables and data are carried through unchanged.