pub struct CreateServiceAccountRequest {
pub username: String,
pub is_admin: Option<bool>,
pub operator: Option<bool>,
pub add_to_deployers: Option<bool>,
}Fields
username: Stringis_admin: Option<bool>Grant the service account workspace admin. Defaults to false. Cannot be combined with operator=true.
operator: Option<bool>Make the service account an operator. Defaults to true for backward compatibility. Set to false to count as a developer (1 seat) instead of 0.5 seat.
add_to_deployers: Option<bool>Add the service account to the workspace wm_deployers group on creation. Recommended when the account will be used as a CLI sync / CI deploy identity so it can deploy on behalf of other users.
Implementations
Sourceimpl CreateServiceAccountRequest
impl CreateServiceAccountRequest
pub fn new(username: String) -> CreateServiceAccountRequest