pub struct CreateWorkspaceFork {
pub id: String,
pub name: String,
pub color: Option<String>,
pub forked_datatables: Option<Vec<CreateWorkspaceForkForkedDatatablesInner>>,
pub is_dev_workspace: Option<bool>,
pub lock_prod_deploy: Option<bool>,
pub lock_prod_forking: Option<bool>,
pub copy_members: Option<bool>,
}Fields
id: Stringname: Stringcolor: Option<String>forked_datatables: Option<Vec<CreateWorkspaceForkForkedDatatablesInner>>is_dev_workspace: Option<bool>Create the fork as a persistent dev workspace (id not required to carry the wm-fork- prefix; at most one per parent)
lock_prod_deploy: Option<bool>When creating a dev workspace, lock the parent (prod) against direct deployment
lock_prod_forking: Option<bool>When creating a dev workspace, prevent forking the parent (prod)
copy_members: Option<bool>Copy the parent’s members (users + group memberships) into the fork so the team can work in it
Implementations
Sourceimpl CreateWorkspaceFork
impl CreateWorkspaceFork
pub fn new(id: String, name: String) -> CreateWorkspaceFork