pub struct DataTableSettingsDatatablesValueGovernedBy {
pub workspace_id: String,
pub datatable: String,
}Expand description
DataTableSettingsDatatablesValueGovernedBy : On a clone, the data table it was copied from, whose roles it takes. Server-owned like reference.
Fields
workspace_id: Stringdatatable: StringImplementations
Sourceimpl DataTableSettingsDatatablesValueGovernedBy
impl DataTableSettingsDatatablesValueGovernedBy
Sourcepub fn new(
workspace_id: String,
datatable: String,
) -> DataTableSettingsDatatablesValueGovernedBy
pub fn new( workspace_id: String, datatable: String, ) -> DataTableSettingsDatatablesValueGovernedBy
On a clone, the data table it was copied from, whose roles it takes. Server-owned like reference.