pub enum DeliveryType {
Push,
Pull,
}Expand description
DeliveryType : Delivery mode for messages. ‘push’ for HTTP push delivery where messages are sent to a webhook endpoint, ‘pull’ for polling where the trigger actively fetches messages. Delivery mode for messages. ‘push’ for HTTP push delivery where messages are sent to a webhook endpoint, ‘pull’ for polling where the trigger actively fetches messages.
Variants