EditErrorHandlerNew

Struct EditErrorHandlerNew 

pub struct EditErrorHandlerNew {
    pub path: Option<String>,
    pub extra_args: Option<HashMap<String, Value>>,
    pub muted_on_cancel: Option<bool>,
    pub muted_on_user_path: Option<bool>,
    pub fallback_to_instance_alerts: Option<bool>,
}
EditErrorHandlerNew : New grouped format for editing error handler

Fields

path: Option<String>

Path to the error handler script or flow

extra_args: Option<HashMap<String, Value>>

The arguments to pass to the script or flow

muted_on_cancel: Option<bool>muted_on_user_path: Option<bool>fallback_to_instance_alerts: Option<bool>

Report failed jobs to the instance critical alert channels when no workspace error handler is set. Omit to leave the stored value untouched.

Implementations

Source

impl EditErrorHandlerNew

pub fn new() -> EditErrorHandlerNew

New grouped format for editing error handler