pub struct FlowConversationRunningTurn {
pub job_id: Uuid,
pub user_seq: i64,
}Expand description
FlowConversationRunningTurn : The turn the conversation is still answering, set by the list endpoint: its newest user message, while the flow run it started is queued or running. A run into this conversation is refused with 409 until the turn ends.
Fields
job_id: UuidThe flow run of the turn
user_seq: i64created_seq of the user message that started the turn
Implementations
Sourceimpl FlowConversationRunningTurn
impl FlowConversationRunningTurn
Sourcepub fn new(job_id: Uuid, user_seq: i64) -> FlowConversationRunningTurn
pub fn new(job_id: Uuid, user_seq: i64) -> FlowConversationRunningTurn
The turn the conversation is still answering, set by the list endpoint: its newest user message, while the flow run it started is queued or running. A run into this conversation is refused with 409 until the turn ends.