pub struct ForloopFlow {
pub modules: Vec<FlowModule>,
pub iterator: Box<InputTransform>,
pub skip_failures: bool,
pub type: Type,
pub parallel: Option<bool>,
pub parallelism: Option<Box<InputTransform>>,
pub squash: Option<bool>,
}Expand description
ForloopFlow : Executes nested modules in a loop over an iterator. Inside the loop, use ‘flow_input.iter.value’ to access the current iteration value, and ‘flow_input.iter.index’ for the index. Supports parallel execution for better performance on I/O-bound operations
Fields
modules: Vec<FlowModule>Steps to execute for each iteration. These can reference the iteration value via ‘flow_input.iter.value’
iterator: Box<InputTransform>skip_failures: boolIf true, iteration failures don’t stop the loop. Failed iterations return null
type: Typeparallel: Option<bool>If true, iterations run concurrently (faster for I/O-bound operations). Use with parallelism to control concurrency
parallelism: Option<Box<InputTransform>>squash: Option<bool>Implementations
Sourceimpl ForloopFlow
impl ForloopFlow
Sourcepub fn new(
modules: Vec<FlowModule>,
iterator: InputTransform,
skip_failures: bool,
type: Type,
) -> ForloopFlow
pub fn new( modules: Vec<FlowModule>, iterator: InputTransform, skip_failures: bool, type: Type, ) -> ForloopFlow
Executes nested modules in a loop over an iterator. Inside the loop, use ‘flow_input.iter.value’ to access the current iteration value, and ‘flow_input.iter.index’ for the index. Supports parallel execution for better performance on I/O-bound operations