pub struct GetBillableSeats200Response {
pub developers: Option<i32>,
pub operators: Option<i32>,
pub seats: i32,
}Fields
developers: Option<i32>Omitted when the seats counted are another workspace’s, as they are for a fork resolving to its billing root.
operators: Option<i32>Omitted when the seats counted are another workspace’s, as they are for a fork resolving to its billing root.
seats: i32Implementations
Sourceimpl GetBillableSeats200Response
impl GetBillableSeats200Response
pub fn new(seats: i32) -> GetBillableSeats200Response