pub struct GetSqsTrigger200Response {Show 26 fields
pub queue_url: String,
pub aws_auth_resource_type: AwsAuthResourceType,
pub aws_resource_path: String,
pub message_attributes: Option<Option<Vec<String>>>,
pub server_id: Option<String>,
pub last_server_ping: Option<String>,
pub error: Option<String>,
pub error_handler_path: Option<String>,
pub error_handler_args: Option<HashMap<String, Value>>,
pub retry: Option<Box<Retry>>,
pub path: String,
pub script_path: String,
pub permissioned_as: String,
pub extra_perms: HashMap<String, bool>,
pub workspace_id: String,
pub edited_by: String,
pub edited_at: String,
pub is_flow: bool,
pub mode: TriggerMode,
pub labels: Option<Vec<String>>,
pub draft_only: Option<bool>,
pub is_draft: bool,
pub draft_saved_at: Option<String>,
pub no_deployed: Option<bool>,
pub draft: Option<HashMap<String, Value>>,
pub other_drafts_users: Option<Vec<UserDraftOverlayOtherDraftsUsersInner>>,
}Fields
queue_url: StringThe full URL of the AWS SQS queue to poll for messages
aws_auth_resource_type: AwsAuthResourceTypeaws_resource_path: StringPath to the AWS resource containing credentials or OIDC configuration
message_attributes: Option<Option<Vec<String>>>Array of SQS message attribute names to include with each message
server_id: Option<String>ID of the server currently handling this trigger (internal)
last_server_ping: Option<String>Timestamp of last server heartbeat (internal)
error: Option<String>Last error message if the trigger failed
error_handler_path: Option<String>Path to a script or flow to run when the triggered job fails
error_handler_args: Option<HashMap<String, Value>>The arguments to pass to the script or flow
retry: Option<Box<Retry>>path: StringThe unique Windmill path for this trigger. Must be of the form u/<user>/<path> or f/<folder>/<path>. This is the trigger object path, not the HTTP route path.
script_path: StringPath to the script or flow to execute when triggered
permissioned_as: StringThe user or group this trigger runs as (permissioned_as)
extra_perms: HashMap<String, bool>Additional permissions for this trigger
workspace_id: StringThe workspace this trigger belongs to
edited_by: StringUsername of the last person who edited this trigger
edited_at: StringTimestamp of the last edit
is_flow: boolTrue if script_path points to a flow, false if it points to a script
mode: TriggerModelabels: Option<Vec<String>>draft_only: Option<bool>True when this row is a per-user draft with no deployed trigger at the same path. Set by list endpoints when include_draft_only=true synthesizes the row from the draft. Frontend renders a "Draft" badge.
is_draft: booldraft_saved_at: Option<String>no_deployed: Option<bool>draft: Option<HashMap<String, Value>>other_drafts_users: Option<Vec<UserDraftOverlayOtherDraftsUsersInner>>Other workspace users (and the legacy NULL-email row, if any) with a saved draft at the same path. Populated only on the authed user’s "get by path" responses for kinds the editor surfaces a fork banner for (script, flow, app, raw_app). Empty / omitted for kinds without that UI.
Implementations
Sourceimpl GetSqsTrigger200Response
impl GetSqsTrigger200Response
pub fn new( queue_url: String, aws_auth_resource_type: AwsAuthResourceType, aws_resource_path: String, path: String, script_path: String, permissioned_as: String, extra_perms: HashMap<String, bool>, workspace_id: String, edited_by: String, edited_at: String, is_flow: bool, mode: TriggerMode, is_draft: bool, ) -> GetSqsTrigger200Response