pub struct GitlabProject {
pub path_with_namespace: String,
pub http_url_to_repo: String,
pub default_branch: Option<String>,
}Expand description
GitlabProject : a GitLab project a token can sync, as the resource form needs it
Fields
path_with_namespace: Stringnested group path plus project name, which is also GitLab’s project id
http_url_to_repo: Stringdefault_branch: Option<String>Implementations
Sourceimpl GitlabProject
impl GitlabProject
Sourcepub fn new(
path_with_namespace: String,
http_url_to_repo: String,
) -> GitlabProject
pub fn new( path_with_namespace: String, http_url_to_repo: String, ) -> GitlabProject
a GitLab project a token can sync, as the resource form needs it