pub struct HiddenItemsSummary {
pub total: i32,
pub by_kind: HashMap<String, i32>,
pub items: Vec<HiddenItem>,
}Fields
total: i32Total number of hidden items on this side
by_kind: HashMap<String, i32>Count of hidden items keyed by item kind (always populated)
items: Vec<HiddenItem>Kind and path of each hidden item; only populated when the caller is an admin of the relevant side (empty otherwise)
Implementations
Sourceimpl HiddenItemsSummary
impl HiddenItemsSummary
pub fn new( total: i32, by_kind: HashMap<String, i32>, items: Vec<HiddenItem>, ) -> HiddenItemsSummary