Module memory_window

Module memory_window 

Structs

MemoryWindow
MemoryWindow : Keeps the most recent messages of the memory named by the run’s memory id (or the step’s memory_id). Without a memory id the agent runs without memory.

Enums

Kind