pub struct MemoryWindow {
pub kind: Kind,
pub context_length: i32,
}Expand description
MemoryWindow : Keeps the most recent messages of the memory named by the run’s memory id (or the step’s memory_id). Without a memory id the agent runs without memory.
Fields
kind: Kindcontext_length: i32Number of most recent messages to load and store. 0 turns memory off.
Implementations
Sourceimpl MemoryWindow
impl MemoryWindow
Sourcepub fn new(kind: Kind, context_length: i32) -> MemoryWindow
pub fn new(kind: Kind, context_length: i32) -> MemoryWindow
Keeps the most recent messages of the memory named by the run’s memory id (or the step’s memory_id). Without a memory id the agent runs without memory.