pub struct ProjectLogoBodyLogo {
pub b64: String,
pub mime: Mime,
}Expand description
ProjectLogoBodyLogo : the logo to set, or null to clear the project’s current logo
Fields
b64: Stringbase64-encoded image bytes (decoded size max 512KB)
mime: MimeImplementations
Sourceimpl ProjectLogoBodyLogo
impl ProjectLogoBodyLogo
Sourcepub fn new(b64: String, mime: Mime) -> ProjectLogoBodyLogo
pub fn new(b64: String, mime: Mime) -> ProjectLogoBodyLogo
the logo to set, or null to clear the project’s current logo