pub struct UpdateAppRawSourceRequest {
pub path: Option<String>,
pub summary: Option<String>,
pub value: Box<UpdateAppRawSourceRequestValue>,
pub policy: Option<Box<Policy>>,
pub deployment_message: Option<String>,
pub custom_path: Option<String>,
pub preserve_on_behalf_of: Option<bool>,
pub labels: Option<Vec<String>>,
pub skip_draft_deletion: Option<bool>,
pub allow_kind_change: Option<bool>,
}Fields
path: Option<String>summary: Option<String>value: Box<UpdateAppRawSourceRequestValue>policy: Option<Box<Policy>>deployment_message: Option<String>custom_path: Option<String>preserve_on_behalf_of: Option<bool>When true and the caller is a member of the ‘wm_deployers’ group, preserves the original on_behalf_of value in the policy instead of overwriting it.
labels: Option<Vec<String>>skip_draft_deletion: Option<bool>When true (set by the CLI / git sync), deploying this app does not delete an existing user draft at the same path.
allow_kind_change: Option<bool>When true, this deploy may switch the app between low-code and raw. Without it, deploying a value to an app of the other kind is refused so an app is never converted by accident.
Implementations
Sourceimpl UpdateAppRawSourceRequest
impl UpdateAppRawSourceRequest
pub fn new(value: UpdateAppRawSourceRequestValue) -> UpdateAppRawSourceRequest