pub struct UpdateAppRawSourceRequestValue {
pub files: HashMap<String, String>,
pub runnables: Option<Value>,
pub data: Option<Value>,
}Expand description
UpdateAppRawSourceRequestValue : The raw app’s value. files maps each source path (e.g. /index.tsx, /App.tsx, /package.json) to its content and must contain an entry point (/index.tsx, /index.ts or /index.js); runnables and data are carried through unchanged.
Fields
files: HashMap<String, String>runnables: Option<Value>data: Option<Value>Implementations
Sourceimpl UpdateAppRawSourceRequestValue
impl UpdateAppRawSourceRequestValue
Sourcepub fn new(files: HashMap<String, String>) -> UpdateAppRawSourceRequestValue
pub fn new(files: HashMap<String, String>) -> UpdateAppRawSourceRequestValue
The raw app’s value. files maps each source path (e.g. /index.tsx, /App.tsx, /package.json) to its content and must contain an entry point (/index.tsx, /index.ts or /index.js); runnables and data are carried through unchanged.