pub enum UserDraftItemKind {
Show 24 variants
Script,
Flow,
App,
RawApp,
Resource,
Variable,
TriggerSchedule,
TriggerWebhook,
TriggerDefaultEmail,
TriggerEmail,
TriggerHttp,
TriggerWebsocket,
TriggerPostgres,
TriggerKafka,
TriggerNats,
TriggerMqtt,
TriggerSqs,
TriggerGcp,
TriggerAzure,
TriggerPoll,
TriggerCli,
TriggerNextcloud,
TriggerGoogle,
TriggerGithub,
}Expand description
UserDraftItemKind : Closed set of item kinds a user can autosave as a draft. Mirrors the Postgres DRAFT_KIND enum and the backend UserDraftItemKind.
Closed set of item kinds a user can autosave as a draft. Mirrors the Postgres DRAFT_KIND enum and the backend UserDraftItemKind.
Variants
Script
Flow
App
RawApp
Resource
Variable
TriggerSchedule
TriggerWebhook
TriggerDefaultEmail
TriggerEmail
TriggerHttp
TriggerWebsocket
TriggerPostgres
TriggerKafka
TriggerNats
TriggerMqtt
TriggerSqs
TriggerGcp
TriggerAzure
TriggerPoll
TriggerCli
TriggerNextcloud
TriggerGoogle
TriggerGithub