pub struct AssetGraphRunnablesInnerDbt {
pub model_count: i32,
}Expand description
AssetGraphRunnablesInnerDbt : Set on a dbt script, which owns a whole project rather than a single output. Omitted otherwise.
Fields
model_count: i32Implementations
Sourceimpl AssetGraphRunnablesInnerDbt
impl AssetGraphRunnablesInnerDbt
Sourcepub fn new(model_count: i32) -> AssetGraphRunnablesInnerDbt
pub fn new(model_count: i32) -> AssetGraphRunnablesInnerDbt
Set on a dbt script, which owns a whole project rather than a single output. Omitted otherwise.