pub struct AzureTrigger {Show 22 fields
pub azure_resource_path: String,
pub azure_mode: AzureMode,
pub scope_resource_id: String,
pub topic_name: Option<Option<String>>,
pub subscription_name: String,
pub event_type_filters: Option<Option<Vec<String>>>,
pub server_id: Option<String>,
pub last_server_ping: Option<String>,
pub error: Option<String>,
pub error_handler_path: Option<String>,
pub error_handler_args: Option<HashMap<String, Value>>,
pub retry: Option<Box<Retry>>,
pub path: String,
pub script_path: String,
pub permissioned_as: String,
pub extra_perms: HashMap<String, bool>,
pub workspace_id: String,
pub edited_by: String,
pub edited_at: String,
pub is_flow: bool,
pub mode: TriggerMode,
pub labels: Option<Vec<String>>,
}Expand description
AzureTrigger : An Azure Event Grid trigger that executes a script or flow when events arrive.
Fields
azure_resource_path: Stringazure_mode: AzureModescope_resource_id: StringARM resource ID of the topic (basic) or namespace (namespace modes).
topic_name: Option<Option<String>>Topic name within the namespace (namespace modes only).
subscription_name: Stringevent_type_filters: Option<Option<Vec<String>>>server_id: Option<String>last_server_ping: Option<String>error: Option<String>error_handler_path: Option<String>error_handler_args: Option<HashMap<String, Value>>The arguments to pass to the script or flow
retry: Option<Box<Retry>>path: StringThe unique path identifier for this trigger
script_path: StringPath to the script or flow to execute when triggered
permissioned_as: StringThe user or group this trigger runs as (permissioned_as)
extra_perms: HashMap<String, bool>Additional permissions for this trigger
workspace_id: StringThe workspace this trigger belongs to
edited_by: StringUsername of the last person who edited this trigger
edited_at: StringTimestamp of the last edit
is_flow: boolTrue if script_path points to a flow, false if it points to a script
mode: TriggerModelabels: Option<Vec<String>>Implementations
Sourceimpl AzureTrigger
impl AzureTrigger
Sourcepub fn new(
azure_resource_path: String,
azure_mode: AzureMode,
scope_resource_id: String,
subscription_name: String,
path: String,
script_path: String,
permissioned_as: String,
extra_perms: HashMap<String, bool>,
workspace_id: String,
edited_by: String,
edited_at: String,
is_flow: bool,
mode: TriggerMode,
) -> AzureTrigger
pub fn new( azure_resource_path: String, azure_mode: AzureMode, scope_resource_id: String, subscription_name: String, path: String, script_path: String, permissioned_as: String, extra_perms: HashMap<String, bool>, workspace_id: String, edited_by: String, edited_at: String, is_flow: bool, mode: TriggerMode, ) -> AzureTrigger
An Azure Event Grid trigger that executes a script or flow when events arrive.