Structs
- Data
Metric - DataMetric : One
// measureor// dimensiondeclaration, as catalogued from the script that materializes the table.exprandfilterare the author’s own SQL: a reader renders a measure asexprplus, whenfilteris set, a trailingFILTER (WHERE filter).