DatatableRoleCluster : The Windmill-managed Postgres cluster a data table role is a login on: Windmill’s own (behind instance data tables) or the external instance cluster (behind external_instance ones). Defaults to instance.
The Windmill-managed Postgres cluster a data table role is a login on: Windmill’s own (behind instance data tables) or the external instance cluster (behind external_instance ones). Defaults to instance.