pub struct EditFlow {Show 14 fields
pub summary: String,
pub description: Option<String>,
pub value: Box<FlowValue>,
pub schema: Option<Value>,
pub on_behalf_of_email: Option<String>,
pub path: Option<String>,
pub tag: Option<String>,
pub ws_error_handler_muted: Option<bool>,
pub priority: Option<i32>,
pub dedicated_worker: Option<bool>,
pub timeout: Option<f64>,
pub visible_to_runner_only: Option<bool>,
pub preserve_on_behalf_of: Option<bool>,
pub labels: Option<Vec<String>>,
}Fields
summary: StringShort description of what this flow does
description: Option<String>Detailed documentation for this flow
value: Box<FlowValue>schema: Option<Value>JSON Schema for flow inputs. Use this to define input parameters, their types, defaults, and validation. For resource inputs, set type to ‘object’ and format to ‘resource-
on_behalf_of_email: Option<String>path: Option<String>tag: Option<String>ws_error_handler_muted: Option<bool>priority: Option<i32>dedicated_worker: Option<bool>timeout: Option<f64>visible_to_runner_only: Option<bool>preserve_on_behalf_of: Option<bool>When true and the caller is a member of the ‘wm_deployers’ group, preserves the original on_behalf_of_email value instead of overwriting it.
labels: Option<Vec<String>>Implementations