pub struct GetScriptByPath200Response {Show 50 fields
pub workspace_id: Option<String>,
pub hash: String,
pub path: String,
pub parent_hashes: Option<Vec<String>>,
pub summary: String,
pub description: String,
pub content: String,
pub created_by: String,
pub created_at: String,
pub archived: bool,
pub schema: Option<Value>,
pub deleted: bool,
pub is_template: bool,
pub extra_perms: HashMap<String, bool>,
pub lock: Option<String>,
pub lock_error_logs: Option<String>,
pub language: ScriptLang,
pub kind: Kind,
pub starred: bool,
pub tag: Option<String>,
pub draft_only: Option<bool>,
pub envs: Option<Vec<String>>,
pub concurrent_limit: Option<i32>,
pub concurrency_time_window_s: Option<i32>,
pub concurrency_key: Option<String>,
pub debounce_key: Option<String>,
pub debounce_delay_s: Option<i32>,
pub debounce_args_to_accumulate: Option<Vec<String>>,
pub max_total_debouncing_time: Option<i32>,
pub max_total_debounces_amount: Option<i32>,
pub cache_ttl: Option<f64>,
pub dedicated_worker: Option<bool>,
pub ws_error_handler_muted: Option<bool>,
pub priority: Option<i32>,
pub restart_unless_cancelled: Option<bool>,
pub timeout: Option<i32>,
pub delete_after_secs: Option<i32>,
pub visible_to_runner_only: Option<bool>,
pub auto_kind: Option<String>,
pub codebase: Option<String>,
pub has_preprocessor: bool,
pub on_behalf_of_email: Option<String>,
pub modules: Option<Option<HashMap<String, ScriptModule>>>,
pub labels: Option<Vec<String>>,
pub inherited_labels: Option<Vec<String>>,
pub is_draft: bool,
pub draft_saved_at: Option<String>,
pub no_deployed: Option<bool>,
pub draft: Option<HashMap<String, Value>>,
pub other_drafts_users: Option<Vec<UserDraftOverlayOtherDraftsUsersInner>>,
}Fields
workspace_id: Option<String>hash: Stringpath: Stringparent_hashes: Option<Vec<String>>The first element is the direct parent of the script, the second is the parent of the first, etc
summary: Stringdescription: Stringcontent: Stringcreated_by: Stringcreated_at: Stringarchived: boolschema: Option<Value>deleted: boolis_template: boolextra_perms: HashMap<String, bool>lock: Option<String>lock_error_logs: Option<String>language: ScriptLangkind: Kindstarred: booltag: Option<String>draft_only: Option<bool>envs: Option<Vec<String>>concurrent_limit: Option<i32>concurrency_time_window_s: Option<i32>concurrency_key: Option<String>debounce_key: Option<String>debounce_delay_s: Option<i32>debounce_args_to_accumulate: Option<Vec<String>>max_total_debouncing_time: Option<i32>max_total_debounces_amount: Option<i32>cache_ttl: Option<f64>dedicated_worker: Option<bool>ws_error_handler_muted: Option<bool>priority: Option<i32>restart_unless_cancelled: Option<bool>timeout: Option<i32>delete_after_secs: Option<i32>If set, delete the job’s args, result and logs after this many seconds following job completion
visible_to_runner_only: Option<bool>auto_kind: Option<String>codebase: Option<String>has_preprocessor: boolon_behalf_of_email: Option<String>modules: Option<Option<HashMap<String, ScriptModule>>>Additional script modules keyed by relative file path
labels: Option<Vec<String>>inherited_labels: Option<Vec<String>>Labels inherited from the parent folder, computed at read time. Read-only — edit them on the folder.
is_draft: booldraft_saved_at: Option<String>no_deployed: Option<bool>draft: Option<HashMap<String, Value>>other_drafts_users: Option<Vec<UserDraftOverlayOtherDraftsUsersInner>>Other workspace users (and the legacy NULL-email row, if any) with a saved draft at the same path. Populated only on the authed user’s "get by path" responses for kinds the editor surfaces a fork banner for (script, flow, app, raw_app). Empty / omitted for kinds without that UI.
Implementations
Sourceimpl GetScriptByPath200Response
impl GetScriptByPath200Response
pub fn new( hash: String, path: String, summary: String, description: String, content: String, created_by: String, created_at: String, archived: bool, deleted: bool, is_template: bool, extra_perms: HashMap<String, bool>, language: ScriptLang, kind: Kind, starred: bool, has_preprocessor: bool, is_draft: bool, ) -> GetScriptByPath200Response