Enums
- Memory
Config - MemoryConfig : Managed memory, stored by Windmill and replayed with each request. The memory is named by a memory id, see
memory_id. While it is off, a step can supply its history inprevious_messages.
memory_id. While it is off, a step can supply its history in previous_messages.