TriggerFilter : Either a leaf filter, matching a field of the message (parsed as JSON) against a value by equality (or superset, when the value is an object or array) — addressed by key for a top-level field or path for a dotted path into nested objects — or a group nesting sub-filters under a boolean operator (none_of matches when none of its sub-filters do).
Either a leaf filter, matching a field of the message (parsed as JSON) against a value by equality (or superset, when the value is an object or array) — addressed by key for a top-level field or path for a dotted path into nested objects — or a group nesting sub-filters under a boolean operator (none_of matches when none of its sub-filters do).